@@ -1,12 +1,12 @@
-use crate::{RaftApp, RaftCore};
+use crate::RaftCore;
 use std::sync::atomic::Ordering;
 use std::sync::Arc;
 use std::time::Duration;
 
-struct Thread<A: RaftApp> {
-    core: Arc<RaftCore<A>>,
+struct Thread {
+    core: Arc<RaftCore>,
 }
-impl<A: RaftApp> Thread<A> {
+impl Thread {
     async fn run(self) {
         loop {
             while let Ok(true) = tokio::spawn({
@@ -30,7 +30,7 @@ impl<A: RaftApp> Thread<A> {
         }
     }
 }
-pub async fn run<A: RaftApp>(core: Arc<RaftCore<A>>) {
+pub(crate) async fn run(core: Arc<RaftCore>) {
     let x = Thread { core };
     x.run().await
 }
