@@ -1,11 +1,11 @@
-use crate::{RaftApp, RaftCore};
+use crate::RaftCore;
 use std::sync::Arc;
 use std::time::Duration;
 
-struct Thread<A: RaftApp> {
-    core: Arc<RaftCore<A>>,
+struct Thread {
+    core: Arc<RaftCore>,
 }
-impl<A: RaftApp> Thread<A> {
+impl Thread {
     async fn run(self) {
         loop {
             tokio::time::sleep(Duration::from_secs(1)).await;
@@ -15,7 +15,7 @@ impl<A: RaftApp> Thread<A> {
         }
     }
 }
-pub async fn run<A: RaftApp>(core: Arc<RaftCore<A>>) {
+pub(crate) async fn run(core: Arc<RaftCore>) {
     let x = Thread { core };
     x.run().await
 }
